@@ -11,12 +11,12 @@ function(solution, taxlevels='ALL') {
             Allresults[[nameres]] <- tmp  # add extracted table as sub-object to output list and label it with the appropriate taxlevel nr.
         }
     }  # if only a specific taxlevel is requested
-    if (taxlevels != 'ALL' & class(taxlevels) != 'numeric') {  # if named taxlevel requested
+    if (taxlevels != 'ALL' & inherits(taxlevels, 'numeric')) {  # if named taxlevel requested
         nameres <- paste(taxlevels)
         tmp <- (solution[[taxlevels]]$result)
         Allresults[[nameres]] <- tmp
     }
-    if (class(taxlevels) == 'numeric') {
+    if (inherits(taxlevels, 'numeric')) {
         if (taxlevels > length(solution)) {  # test whether requested taxlevel is among available ones and display error if not
             stop('Requested taxonomic level not available (less levels specified as analysis input)!')
         }
